serve_inner

Function serve_inner 

async fn serve_inner(
    config: Config,
    timely_config: TimelyConfig,
) -> Result<(Vec<Thread>, impl Fn() -> Box<dyn ComputeClient> + use<>), Error>
Builds the Timely cluster for the given config and returns its worker threads along with a builder for compute clients to it.